@@ -34,7 +34,7 @@ class ExpectedGoogleException(Exception):
 
 
 class Google:
-    def __init__(self, config, save_failure, defaults: CLIDefaults):
+    def __init__(self, config, save_failure, defaults: CLIDefaults, secrets_mgr: SecretsManager):
         """The Google object holds authentication state
         for a given session. You need to supply:
         username: FQDN Google username, eg first.last@example.com
@@ -51,7 +51,7 @@ class Google:
         self.save_failure = save_failure
         self.session_state = None
         self._defaults = defaults
-        self._secrets = SecretsManager()
+        self._secrets_mgr = secrets_mgr
 
     @property
     def login_url(self):
@@ -683,7 +683,7 @@ class Google:
 
         if self._defaults.mfa_enabled:
             color = Utils.default_colors() if self._defaults.colors_enabled else None
-            mfa_token = self._secrets.get_next_mfa(self._defaults.user) if self._defaults.auto_mfa else \
+            mfa_token = self._secrets_mgr.get_next_mfa(self._defaults.user) if self._defaults.auto_mfa else \
                 Input.get_mfa(display_hint=True, color=color)
         else:
             mfa_token = None
@@ -880,7 +880,7 @@ class Google:
         # if challenge_id == 2:
         #     if self._defaults.mfa_enabled:
         #         color = Utils.default_colors() if self._defaults.colors_enabled else None
-        #         mfa_token = self._secrets.get_next_mfa(self._defaults.user) if self._defaults.auto_mfa else \
+        #         mfa_token = self._secrets_mgr.get_next_mfa(self._defaults.user) if self._defaults.auto_mfa else \
         #             Input.get_mfa(display_hint=True, color=color)
         #     else:
         #         mfa_token = None
