@@ -1,3 +1,4 @@
+from figcli.svcs.secrets.figgy_keyring import FiggyKeyring
 from figcli.utils.utils import *
 import platform
 import keyring
@@ -13,9 +14,10 @@ class SecretsManager:
 
     def __init__(self):
         self._last_token = 9999999999
+        self._keyring_pw = None
+        self.set_keyring()
 
-    @staticmethod
-    def set_keyring():
+    def set_keyring(self):
         if platform.system() == WINDOWS:
             keyring.set_keyring(WinVaultKeyring())
         elif os.environ.get(OVERRIDE_KEYRING_ENV_VAR) == "true":  # Used in builds when running tests
@@ -23,7 +25,7 @@ class SecretsManager:
         elif platform.system() == MAC:
             keyring.set_keyring(keyring.backends.OS_X.Keyring())
         elif platform.system() == LINUX:
-            keyring.set_keyring(EncryptedKeyring())
+            keyring.set_keyring(FiggyKeyring())
         else:
             Utils.stc_error_exit("Only OSX and MAC and Linux with installed SecretStorage are supported for "
                                  "OKTA + Keyring integration.")
@@ -38,43 +40,24 @@ class SecretsManager:
         self._last_token = token
         return token
 
-    @staticmethod
-    def generate_mfa(user: str) -> str:
-        SecretsManager.set_keyring()
+    def generate_mfa(self, user: str) -> str:
         mfa_secret = keyring.get_password(FIGGY_KEYRING_NAMESPACE, f'{user}-mfa')
         token = pyotp.TOTP(mfa_secret).now()
         print(f"Authenticating with one-time token: {token}")
         return token
 
-    @staticmethod
-    def set_mfa_secret(user: str, mfa_secret: str):
-        SecretsManager.set_keyring()
+    def set_mfa_secret(self, user: str, mfa_secret: str):
         keyring.set_password(FIGGY_KEYRING_NAMESPACE, f'{user}-mfa', mfa_secret)
 
-    @staticmethod
-    def set_password(user: str, password: str) -> None:
-        SecretsManager.set_keyring()
+    def set_password(self, user: str, password: str) -> None:
         keyring.set_password(FIGGY_KEYRING_NAMESPACE, user, password)
 
-    @staticmethod
-    def get_or_set(user: str, backup: str):
-        current = SecretsManager.get_password(user)
+    def get_or_set(self, user: str, backup: str):
+        current = self.get_password(user)
         if not current:
-            SecretsManager.set_password(user, backup)
+            self.set_password(user, backup)
 
         return current
 
-    @staticmethod
-    def get_password(user: str) -> str:
-        if platform.system() == WINDOWS:
-            keyring.set_keyring(WinVaultKeyring())
-        elif os.environ.get(OVERRIDE_KEYRING_ENV_VAR) == "true":  # Used in circleci builds for running tests
-            keyring.set_keyring(PlaintextKeyring())
-        elif platform.system() == MAC:
-            keyring.set_keyring(keyring.backends.OS_X.Keyring())
-        elif platform.system() == LINUX:
-            keyring.set_keyring(EncryptedKeyring())
-        else:
-            Utils.stc_error_exit("Only OSX and MAC are supported for OKTA + Keyring integration.")
-
+    def get_password(self, user: str) -> str:
         return keyring.get_password(FIGGY_KEYRING_NAMESPACE, user)
